header {
    background-color: #1B1B1B;
    color: #E0E0E0;
    text-align: left;
    padding: 20px 0;
    padding-left: 10px;
    font-size: 28px;
    width: 100vw;
}

body {
    background-color: #333333;
    font-family: 'Montserrat', sans-serif;
    font-weight: 400;
    font-size: 16px; 
    line-height: 1.6; 
    margin: 0;
    padding: 0;
}

div {
    margin-left: 0;
}

h1, h2, h3, p {
    margin: 30px 0 15px 0;
    padding: 0;
    color: #E0E0E0;
}

th {
    background-color: #14274A; 
    color: #E0E0E0;
    border: 2px solid #444444; 
    padding: 12px;
    font-weight: 600;
}

td {
    background-color: #1E3A8A;
    color: #E0E0E0; 
    border: 1px solid #444444;
    padding: 12px;
}

table {
    border-collapse: collapse;
    border-spacing: 0 8px;
    width: 100%;
    margin: 0;
}

h2 {
    font-weight: 700;
    margin: 30px 0 15px 0; 
    padding: 0; 
    color: #E0E0E0; 
    line-height: 1.3; 
    margin-left: 10px;
}

h1 {
    font-weight: 700;
    line-height: 1.3;
    margin: 30px 0 15px 0; 
    padding: 0; 
    color: #E0E0E0; 
    margin-left: 10px;
}

h3 {
    margin: 30px 0 15px 0; 
    padding: 0; 
    color: #E0E0E0; 
    margin-left: 10px;
    font-size: 20px;
}

p {
    color: #F8F0E3;    
    margin: 15px 0;
    padding: 0; 
    color: #E0E0E0; 
    margin-left: 10px;
    font-size: 16px;
    line-height: 1.6;
}

img {
    border: 2px solid #444444; 
    padding: 5px;
    max-width: 100%; 
    height: auto; 
    box-shadow: 0 4px 8px rgba(0, 0, 0, 0.6);
    border-radius: 4px; 
}

.feature-section {
    margin: 0 auto;  
    padding-left: 10px; 
    padding-right: 10px;
}

.flex-container {
    display: flex;
    align-items: flex-start;
    gap: 5px;
    width: 100%;
    margin: 0;
}

.flex-item {
    flex: 1;
    margin: 0;
    padding: 0;
}

.image-container {
    flex: 1;
    text-align: center;
    margin: 0;
    margin-right: 30px;
    padding: 0;
    min-width: 1000px;
}

.feature-table {
    width: 100%;
    margin: 0;
    max-width: 500px;
}

.correlation-matrix-container {
    text-align: center;
    width: 100%;
}

.correlation-matrix-container img {
    max-width: 100%;
    height: auto;
    border: 2px solid #444444;
    padding: 5px;
    box-shadow: 0 4px 8px rgba(0, 0, 0, 0.6);
    border-radius: 4px;
}

.categorical-feature-table {
    width: 100%;
    margin: 0;
    margin-left: 10px;
    max-width: 600px;
}

.pie-plot-container {
    text-align: center;
    margin: 0;
    margin-left: 10px;
    margin-right: 30px;
}

.pie-plot-container img {
    max-width: 100%;
    height: auto;
    border: 2px solid #444444;
    padding: 5px;
    box-shadow: 0 4px 8px rgba(0, 0, 0, 0.6);
    border-radius: 4px;
}
